@@ -1,5 +1,5 @@
 import resotolib.logger
-from dataclasses import dataclass
+from attrs import define
 from typing import Optional, ClassVar
 from resotolib.graph import Graph
 from resotolib.baseresources import (
@@ -7,13 +7,12 @@ from resotolib.baseresources import (
     BaseRegion,
     BaseInstance,
     BaseNetwork,
-    InstanceStatus,
 )
 
 log = resotolib.logger.getLogger("resoto." + __name__)
 
 
-@dataclass(eq=False)
+@define(eq=False, slots=False)
 class OnpremLocation(BaseAccount):
     kind: ClassVar[str] = "onprem_location"
 
@@ -21,7 +20,7 @@ class OnpremLocation(BaseAccount):
         return False
 
 
-@dataclass(eq=False)
+@define(eq=False, slots=False)
 class OnpremRegion(BaseRegion):
     kind: ClassVar[str] = "onprem_region"
 
@@ -29,7 +28,7 @@ class OnpremRegion(BaseRegion):
         return False
 
 
-@dataclass(eq=False)
+@define(eq=False, slots=False)
 class OnpremResource:
     kind: ClassVar[str] = "onprem_resource"
 
@@ -43,26 +42,14 @@ class OnpremResource:
         return False
 
 
-@dataclass(eq=False)
+@define(eq=False, slots=False)
 class OnpremInstance(OnpremResource, BaseInstance):
     kind: ClassVar[str] = "onprem_instance"
     network_device: Optional[str] = None
     network_ip4: Optional[str] = None
     network_ip6: Optional[str] = None
 
-    instance_status_map = {
-        "running": InstanceStatus.RUNNING,
-    }
 
-    def _instance_status_setter(self, value: str) -> None:
-        self._instance_status = self.instance_status_map.get(value, InstanceStatus.UNKNOWN)
-
-
-OnpremInstance.instance_status = property(
-    OnpremInstance._instance_status_getter, OnpremInstance._instance_status_setter
-)
-
-
-@dataclass(eq=False)
+@define(eq=False, slots=False)
 class OnpremNetwork(OnpremResource, BaseNetwork):
     kind: ClassVar[str] = "onprem_network"
